
# q-expansion of newform 50.18.a.g, downloaded from the LMFDB on 05 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 50
weight = 18
poly_data = [-9015, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-80, 160], 1]]

hecke_ring_character_values = None
aps_data = [[256, 0], [3154, -1], [0, 0], [-3271922, 843], [594704352, -12738], [1008959614, -122772], [9377819718, 1944132], [-68352415300, -2994168], [324617085354, -22452951], [-2348271710010, 4841544], [3560433689372, -342178986], [-4966557318722, 1485224712], [4811355940422, -2262047724], [-3854218005926, -8809717953], [233036287918998, -4448723037], [311666560142214, 27224743188], [327308035997580, 85208012868], [664520192581442, 118790012448], [2124508205938798, -126467311491], [1017565974673812, 551192664438], [-1124296730673986, -27932935932], [9594213839247560, -84548615868], [9237324543305994, -203422699965], [-8729456458197510, 882301557960], [-97967162911245122, -252225032820], [34482223585974342, -216723129384], [4290754007818594, 11015308039005], [198960578230956918, -2296440537411], [117803165563328450, 10698466516536], [386211658582002054, 9508260928344], [-229985624377692722, -7604949803121], [-271808616054452448, -21141307830894], [490615370801175918, 4865093846928], [1318379308730321660, 53761455424908], [475106278354318650, 107726836243320], [-2243864977825462348, 219745616978070], [-210131444704311722, -162562957724712], [5823092473703994394, 240412548282915], [2341796822919852798, 287316664346859], [-11418192538562469306, 55866511933320], [-18803856354042557580, -70295746619364], [5493641793907338422, 1285165538139984], [-7044915080407343148, -1270002800411862], [-38382767609152870106, 98549007410340], [26892158552190800238, 895212352475364], [-13162113517539301240, -1324078666901376], [-20628827126099884528, -236139453117870], [-51572518244008943366, -1491253847377899], [61334302532977484598, -4667627809588383], [92808978165391225550, 6907934830766208], [33518469091839739974, 9627545070535212], [-182251448453857083480, -1181931871749708], [-27984509176826356018, -10112773786460220], [-229076128027450335648, -5997737778494970], [172676165553818120838, 10654656027959832], [211308345118218687234, -33330001620792219], [88343303564093405010, 44012163741587376], [22963690056586751732, -9338733051886854], [21994012831908675238, 11478883202119848], [-89501373270494612538, -16425543699277860], [-318937777440201674366, -5562695327809029], [-736536536910150668706, 55445333891397840], [2106508050615929272558, -18260030987946315], [1795247632397075409132, 13970123786745714], [1573353856701075389974, 83925931112572152], [372189564909343665798, -42558263718416196], [-221891534167748910808, 26686328501063322], [-1498683006206668790402, 139541499360588360], [-6419368856439201864882, 87520353852729681], [-3756118144697768752330, 222162931619721648], [2677994331948015042414, -330769852743340872], [-2309472723666984050280, 147941350939643424], [1736308438709341796518, 109884647192831667], [419590994229190326694, 396942564912278520], [375717456414307695140, -398772669398816856], [866742569185946240874, 789115936891674957], [11968405607843636922810, 332448852902999088], [-1830915504859129514882, 1313150877127844076], [10779008745137449396962, 442465151283427104], [1286964265561867418270, 511808736632997084], [14621193059652284671140, -468946338837611172], [-7482994877177685096358, -1453087684780023240], [-16749718214421678385788, 617409802364352210], [5496947373822632419774, -478731804912850548], [-28771020205861373966200, -28312014118192416], [27588800003756979178314, 860109877021665183], [9258818239327144549830, -304834934387578188], [-12914285057500570290842, -3302429183476139520], [36161208080455304217822, 1325516148210157560], [-33040764675953980033886, 1786423724074456713], [8499503994053416259598, -2212443202268998251], [-38386065145302247596120, 194522838096132660], [-41533860991551008245322, 3732506610659809647], [-36279847775067977474208, -2199263309344148106], [-68962442623893773785540, 1175969435227269264], [-16290670663469933097726, 659957418008826117], [-24471636121561784673210, -3270441358933646688], [49443020806520479083642, -2627022145635406080], [-122663663850958533027326, -1741657588595540973], [-12273317336672664904498, 6381790736665205928], [102641272490747810843158, -9865668637671908463], [-261128374837014033700002, -7681236752425566024], [180875741676920140197474, 16790898323252337087], [37145490125012937524190, -10679479583369504052], [-126345709380178518664408, -12109835767880715270], [231467685893185983038998, -1309262726179125648], [-210129029488530454082442, -386180523225963171], [-58176782133203723059986, -19635249229845221472], [490640508072762875941440, -11422107942935816124], [-406228491091965468979018, 10450069879713621132], [74993388143282789840038, -13326754755301136973], [78520038593760115405054, -18925517913942083076], [151069181066510498701638, -26543409390920662020], [-17684296759277023559980, -53613604419835338720], [353755960208240285095172, -7166869947046347906], [557342787099771654475182, 20984327477172846180], [852325808801400124379074, -35434347806211351273], [132537979540114312264998, -3990580748187310857], [-330448718662439557158186, 71340209774606422068], [-1083623950032335733505500, -46466702154073585644], [493107258675512763597482, -9073613923055612496], [-991094016519855034498706, 31330373462523262260], [-129084234831714700975122, -2640954046920213396], [347915207183993959808634, -35919315981622624449], [916478091106948955881832, 112327313977944900990], [160580227093293835000482, -13239018920965763208], [-172990098602298087351010, -40764645787129659768], [402456493151941809534120, -75707119438693991100], [-339546895032831598925762, -13259346628388965317], [-1765406789366561577231146, -16767931442228842176], [-2624286953296579943831020, 33839030791859675076], [-421959503048929240664406, -60677825935784300775], [3369308059090298678424092, -42498760595468984154], [3542159170924628530449238, -16335143466790994928], [-2767013354979696020595798, -100630081580995896288], [4760317812002859372037250, 77508614440530961032], [381785521934501127732894, 105433959952399514100], [-1271367086406528559730282, -154184566112886344247], [2285990774572274272089558, 154336780995852123732], [622071297052403464058490, -121677001503245883648], [3688856006333363529103952, -402567116940180224778], [-4754288980174129141354998, -337005588621328912056], [6153478747715946849431434, -201120310942137661719], [919364327394750852564558, 195705285781465732161], [-4031868145510715556457150, -420552110045711541312], [-992008888994400481127280, -374145679541407013028], [-450041270551764858343346, -615180601172133100476], [-4002512338368000986686482, 551861994042764402664], [-5942608230333076608581380, -600326911783260576756], [-13985754558868306065883926, 14239782031936882677], [7924409559329087448510118, -23933099644582231920], [6070665526965930438665262, -63106765825458747780], [7048789001049072972272194, 440011899391570177215], [-15037908817924467614214402, 229923190584206865195], [18100678353172769412359518, -39607851500285221791], [-12684457305860633394447828, 94026536043612568470], [-12851638146380745263248720, 691964016119319309084], [16710670280304076223873430, -861634295442116266380], [10181937794083634213597398, -967042907528229409260], [-2962372026886313301416658, 1817895733522029676704], [2844570216970398145194078, -1847042443296957202755], [-12384962549460600695644026, -650251935218342659008], [8032797033153245072446438, -216896114235739064625], [2950478304884599016637192, -2443475113806719398470], [-7593685515441651137156562, 83589227985335233428], [33531410619879937191993474, 1174509612494836529037], [1305289293395643629432732, 1967400347440609808190], [26605739776644506776191718, 1317552232366329849756], [-16993086454661426283434830, -481797499622711228136], [12994893112009597821288174, 1853879627875490938572], [-35160864045589274852984220, 450402032038407605544], [30810392155210012781256782, 944343333841561039296], [-3373017256237689136970388, -2611142252522273906310], [3599417679952865958947134, 3334123534165624781196], [-11420535375869396708438800, -4244401885235572873536], [-3901031309864253924502230, 5150414410107864821688], [36128973761569963345921832, 1640547752885111876442], [-19684013578134520424523018, -1537038612597337676736], [-51075906754804490841392966, -240089933353218062439], [42071732332077360339694610, 3291643402806990691776], [52709381989645473130138918, -3226120935733445115957], [5628968353546404499372752, 143524560083389295898], [-11052592770203984003639786, 280352288415318710508], [-12358656780251359435006242, -3969928246781307172188], [19976561049851911004078874, -369202510871278612203], [-55854929417728664277094050, -2150609397648321164424], [63158406672742241287002478, 3222363677808643183656], [-55821496312879883079158846, -5405431165736819989641], [-38554177946407122539733250, 6673971332939790950988], [-43907682737802707982440148, 8491958699154381110310], [-82890165988675220188896746, 2323096572205758128304], [10780161654099262244981274, 6614380417934001038127], [177719491875598580159158712, -1126554917853389879562], [-30079618606168770914486238, 11316854848308195141360], [-153153030184255862106414282, 580609371164306414193], [108305934579052519090219974, -4741234805746940904348], [197995812267655917075355982, -1628617197819749001588], [-180841827790954287656822426, 989902070725193662572], [-143507896016200420188721122, 4508444040456512720256], [-39380402994626281191008046, 330940634502955187109], [165481078775069210596772550, 618385695763401649848], [-174246214228732899528011068, -2076904517235233699862], [-1485691538050823297309162, 14938833465264441753756], [27558273140011054375742930, 12364953305584142584512], [99238939463502105708282300, 8394033286072677962196], [-28905754748323048386896442, -2714564089838879500944], [47662326201870523418279840, 16399699907112654886104], [21022942085446771893501234, 3118104583428527502591], [-197727001341841474093872390, -1796182387086949373592], [-5311241831190878363812648, 1391410724819136419778], [-116376548010224212575199322, -17813931436918194769860], [74315742464330154590364522, 28895746322480200556568], [149992334025513714162853474, 24955660350944962513677], [-210891054891573305493815562, -6309014281445266594443], [131083796992944036552667920, 19853004092439145606980], [294289548802226375905614902, -7174797212168678061036], [126342899527270237107288478, -22986811531564341761361], [-425333066396459112244405998, -22129639092522450079008], [73497883847238123144755838, 3883749625926599243955], [133165164335236373683041774, -2075440668873316676748], [679553299263570772993239002, 9181235430689660720016], [79021047278522975405320160, -9079000822464190757316], [-352851375612149686520500590, 25480881055028665640040], [121350556533531666049406674, -4765808633416420419063], [324901530991434755655630438, 28869686597969925185313], [-62934688219423135539835990, -55509568179295382844288], [-80781824834232033140588706, -11691865321589961186660], [-327575369959180239913361280, -50595515644464858820248], [693077517822200323075839718, 4448476261228077892191], [50732005695302307400920072, 52955316679301712142698], [-406446529036048877821147346, 31930156257734290458804], [616580527930443289588151180, -3427198158300851437992], [-327695656073691583656709468, 54617012545273669499106], [-914638306045412876078690058, -17464033522036404229668], [1076529373161484275689982034, -31766809618777895276229], [-640801866056110250569801362, 181077705685281501591], [-132405460465993349415508090, 45916945489203478784388], [714416058676067000606117334, 49293963697558146023196], [-656513602278547551206184060, -4110512033655524905344], [-549541948738210504832064228, 55929330386860263614850], [68882848713692608725901914, -65975121831862410422037], [-891562769035154533203859168, 3939439538887975016118], [-254602996471406090997191366, -81520529362101125390799], [-205811666131421400313145290, -145754110313409685242096], [-734368364194642199869397346, -7141754792716937325096], [1583340234648883809732665880, 2470814362846188940968], [1066942178869380722006979358, -2634379092665601448137], [-431874068660041339484483688, 3847127304913823995638], [416593157141633633929551740, -100816522629847164314796], [-2339850019615522571804393886, 2087327193400870856553], [-2157142542112806995534454962, 23251866176990099673324], [-17442069431103009691055598, -79864660997151858611040], [446061729453754117257646038, -149253586893567884728113], [-840376068095064700048739890, 159084078620830477485660], [262087712432149089604133574, -13850000366177931242448], [377966613700928240812392780, -165922575580187782307376], [155623448386786841323817222, 93699921951533905864632], [1388333107234875382522522078, 86851339722027939756969], [-458216337086056549312664682, 134644431070995748876968], [-2249106817496705432125736762, -101067156469556745231168], [782017182099777007456407754, -310626300824690828811], [-282530228369103945250739322, 169193551570094253859641], [4211776772569718578092778190, 17493751030859178615648], [-3775886005146790247213530226, -16326893660919758847408], [-194033070234789781824901482, 164920394706412453791036], [-3499478630356295635207195540, -127732603142223081124416], [-3412098023765840520833977530, 156354788188030712443104], [3961276004021396405719294122, 1762307407684940836752], [340376822177573248240673674, -383435169426632645158113], [2447174502015372083485527054, 116576877730748976453384], [-1187826569100371327313877378, -157688812311668139357744], [-2539751020353455034760120082, -44590822420788807044859], [1152878336655180416134605094, -60197891593938047861940], [4725236381938589807276683760, 42984771447624127557840], [-4204504182052779453841734122, 123021592661833914201024], [508629991093420510510875754, 101921628659762781735489], [-2460819091051449455853739362, 35563833986498871709641], [3306329766408947228287469750, -46330245022931504627736], [-2838657083078118163839675418, 135338779445897358873132], [4089513271650716584205308272, -142730207293951069936950], [1080985645949491436287324314, -43357518551816227898787], [4324399039097770450500844892, -142459640442531382306518], [2133516830670854832606753318, 515750933200038350379591], [-3649180844770261244359813498, -448458641024819365641888], [-1463611980803026948014240602, 591524773065627652357749], [-4317030400778478963310133508, -80043196192164402036810], [-4511464846748055835800100826, -368395456849747699440828], [-3854050716679559549566033122, 308626425899305125603564], [928277306733357933132984080, 148947938627025996994140], [-8942177825072626211220452970, 239108977707954125233236], [4346485351213968824343866322, 6843007607796337338648], [-11479667110436223251366635002, 156591903052602236670081], [4453382460684933988445362734, -601757296058619118898484], [616830296554591764904134672, 177283995029804855053614], [-6773687438376746109694585946, 111563745270282722928384], [2898803266099528742596980690, 139129735454707263605256], [-7292303980830067798238966548, -156519817113133761708090], [5862268204809565421011511694, 352630074208499253045360], [-5004055076246045527510989180, -426417504573756649868784], [8909892116629117449088123678, -68270116647332493337563], [-10841426371416847066153470386, 461191334971631959685088], [1090644355188759132099384438, -711084407521280322562296], [-18031096270215745061064199960, 86614936809281517999756], [-5061466980920709995425243806, 220870378031278971841695], [-5783873086062856467430150528, 14339755133667043544070], [10079079429608948641789930558, 660164549244269746407108], [1985298006761720099970911598, -1269710696979275702203143], [6431452079836752576202345910, 284317145855587592809992], [-2668414363750130456567564520, -1454925701353188631289544], [-3096794316478898177599212866, -421674267835714491925704], [7933545736505814025705592634, -942087080779299307031379], [6049325525857735831361423070, 1219616888037980503825680], [-11944359959498308142562701598, -645122910426297500376624], [-4885115336213444702738169566, 337908241111544754238551], [-13933722819559193891588280402, 1206511517700795429349155], [5142203902985258482883913290, 97966095039069170434680], [3650514699048308068134092700, 332672504103537461292840], [-7974261643942336089785374548, -88013750434376173993218], [33838153875073392461324073574, -154624063858759374336168], [-2617196266623857999257489770, 1510209326740086384481140], [3715202675009562802631209832, 1131343482533453681288958], [18992789302767327742392074878, -976658962972916818346448], [10087002251096670780645271842, 519416738252604307455264], [24580456124316859828996071634, 234085774339679821951881], [1258163033958349117074584094, 2543455371667479025313880], [20583354666424229010460310942, 678344192453591074734228], [-17029180454512729778931688180, 194876399495338894282896], [-7495109055274068574196372006, 391988159519394632065335], [-12838774007224751790225392442, -1232375297247502213961325], [20139075211755512744071530294, -1019344045733843306460900], [9827667482032552809376723442, -2639209361730986382395400], [-3757027276854454139969697642, -940916429630188787896416], [9909050092011064052300143640, 2086982189401525945449900], [-2462679115720793464767030726, -770857214223838163408973], [32533955078244731703158616272, 1120355982224595010488798], [-16562049787839852725188262922, 2641238909100547058315061], [6919526248042075310402427890, -942179506534475500179672], [-6456887698009694615780526426, -2766489193454493345395328], [54845293283228208983079650582, -599168222868002051808132], [36283367339864050570813417678, -1620629995695427951985313], [17462673655995214876812664894, 1659038759047259428594080], [16437637784324789445772275798, 876719992204715395674528], [-14028568512461800931644023030, -3420423792137325466757016], [14923837178451823822225673012, -1007976013340126223944274], [-18023315102570071671713807826, 137176666644411369732792], [3918767176981988638315668300, 2688811744193574238707024], [32016360487475370359040345722, 2367561831439029586616736], [18836249239159112799346043998, 2629350632155474980388833], [18619392885290701272113779452, 993892243474261495811670], [-41025199625183104958795631762, -120447078320366474710188], [49785896054218051528574283632, 2149986845279035703586], [8516624627486618959517482678, -1368248435765989096017096], [-14128411847821840818202215438, -1699909584853197825691680], [-36884580923396233424786792846, 518213846938176589613769], [-60400468835641189299965560930, -392622369012180698984928], [-17068457065792127273038350066, 572571865208486082240276], [25112459253305983039272906120, 973850086743517131609228], [-3855848255979209570260201128, 650016209600125853987730], [4967191497962402884270321038, -2995872295167103370980380], [20302419600655150424170250874, -2798476838153891679250503], [33210087886605731967750097078, 5409918048743230551696732], [50456273049091545074958397002, -1652461127865786080931552], [-36722978884618888647549749562, 478842891581566708370739], [-28234302641760320926759307940, -424657519204534598163180], [58219898968221253573662124918, 1706329871199719109735057], [-42901241888937090845388270986, -4305733231954034704132812], [1043704549524990968305625118, 302831380959491196412740], [-47908980501293786595702725486, -1329607134475581005355987], [-70028089044396377995160683978, 814710971312535108540612], [-43548961889356629775379548848, 4056337315820844814851426], [97661497582598547915560371460, -4901506522455948988252272], [-57809612333362098293138749086, 3026530827030040395564153], [55937479739596423711634456730, -2454991088677576584548568], [99063814162510301688112241492, -1914847614305395860869514], [-84147668355942923189555448242, -335657718278943117987300], [-6056101367888916413052933300, 1664906481953310242673168], [-54656202626751559129542682068, -7362606029113768104387210], [52374200116932621649769207854, -2739306582886313488705536], [-97730862686499721490967429690, -1443066266679318557951100], [54764791485364400253465684478, -6861037504183528966410744], [147305744895348830695370157102, -1629553222112478895871616], [84016283418824373790188324174, 502988975403993664533192], [-121151184110873381188229643002, -3221257731884555135337], [-134998792453576530340620528402, -2851036914356862672174384], [47562511838553727627803708860, -5381725584576383893403640], [95155125879282103704121120554, 535048734499865945743569], [35562195891220954801162667972, 1594157314032571428342522], [197255237872750229481898596238, -2092251534271125847904232], [17906327928109201567816306474, -10713853154931045760390113], [-121050542740083176237979692442, -194525127728208938439981], [-145201851469440235072650638410, 4221618427844250894140820], [-10329514952477204116018749546, 3317382939853268318107464], [-73227234683784036532837645860, -2824211380260713493198084], [-60872661473418711692252176322, -3075771996666912360351507], [109952461065563054706461993412, 11757342167199717139310886], [19792939415631335543723234734, 5475135348514302419661696], [-4209858092176995446169933880, -11104860368072578335136140], [-114752802079573972070499901830, -8461887448262578017162624], [-94639271612472043036570924288, 14331426437105747515538670], [-156469880378696458682689737078, 6671319303977352507109296], [-25938676560606980623737817870, -4519345451334124708342728], [162931097358449859411678673254, -4431823404122551493652756], [-32982830372613923761326052442, 18796000455682453102731843], [1573191700398451363525942638, -7648191186031739705279232], [9283137265296752852551961370, 2405704494901622599528032], [-117497838178506210575652268108, 15706971230397689030722614], [-306422857392705690417709512122, -2508807889677765991089660], [9492885600211994965585288722, -9653744169502814812790832], [119424859900424103579776335594, 14492485388837390701617315], [119030421493160730536935192260, -2935183314138905866373244], [87300066909291894732137751214, -277018307355604193401992], [68921121695108916747315708078, 785663871415883514099912], [-87187883239843931183789729886, 7928472740760368154372603], [61841284428776425420841160512, -19203823594159703194778766], [195681867400438976130059101678, -14005858424229241571412012], [138148219650640220121579887742, 3206901144769169008886808], [-77105852030167893714071154720, -11138831861888199238340520], [-194344904304912248598962974322, -7463850294420765653773533], [-116535993146931551289137788962, -22705859690517831020435316], [-115608905236541430142394512086, -15827876104016013153943407], [140043593289379884938433168930, 23419749565731854413994448], [15413297939182764292370841598, 6285247869423519266778924], [208259524700877082096965562518, 16898997403586489348851155], [-214316827774859299188677425860, 10143475760018856231462540], [-31233683480586334077083513546, -8498252918813157786210336], [-3527781012146328425876140122, 17669859827524534297431288], [144929976129278706902370025314, 32018725022360629079623743], [129285929882608509910028170110, 19757225178502683935729676], [-174579442575722346945527912248, 6428716336412700980058234], [45564827852366316102800926440, 6640212726468864890161896]]
